@@ -1,9 +1,10 @@
-from typing import Callable
-import panflute as pf
-from panflute import elements
-
 import io
 import sys
+from typing import Callable
+
+import panflute as pf
+from panflute import elements
+import black
 
 from .types import PythonOutput, FigureContainer
 
@@ -23,6 +24,15 @@ except ImportError:
     sprint("warning: matplotlib not available")
 
 
+def code_formatter(code_text: str) -> str:
+    try:
+        res = black.format_str(code_text, mode=black.FileMode())
+        return res
+    except Exception as err:
+        sprint(f"warning: cannot run black formatting - {err}:\n{str}")
+        return str
+
+
 def py_env_exec() -> Callable:
     """Create env to execute code in"""
     d = dict(locals(), **globals())
@@ -48,7 +58,9 @@ def py_env_exec() -> Callable:
                 print(res)
 
         except SyntaxError as err:
-            sprint(err)
+            # we assume that this is was just part of the full codeblock
+            # and not meant to be output'd
+            pass
 
         # repair default stdout
         sys.stdout = old_stdout
@@ -62,6 +74,15 @@ exec_env = py_env_exec()
 
 
 def action(elem: pf.Element, doc: pf.Doc) -> list:
+    # preprocess code formatting
+    if (
+        isinstance(elem, pf.CodeBlock)
+        and "python" in elem.classes
+        and "no-black" not in elem.classes
+    ):
+        elem.text = code_formatter(elem.text)
+        elem.classes.append("black-d")
+
     # run python code chunks
     if (
         isinstance(elem, pf.CodeBlock)
